@@ -65,7 +65,7 @@ class TupleVariation(object):
 		for axis in axisTags:
 			value = self.axes.get(axis)
 			if value is not None:
-				minValue, value, maxValue = value
+				minValue, value, maxValue = (float(v) for v in value)
 				defaultMinValue = min(value, 0.0)  # -0.3 --> -0.3; 0.7 --> 0.0
 				defaultMaxValue = max(value, 0.0)  # -0.3 -->  0.0; 0.7 --> 0.7
 				if minValue == defaultMinValue and maxValue == defaultMaxValue:
@@ -134,16 +134,19 @@ class TupleVariation(object):
 			flags |= INTERMEDIATE_REGION
 			tupleData.append(intermediateCoord)
 
-		if sharedPoints is not None:
+		points = self.getUsedPoints()
+		if sharedPoints == points:
+			# Only use the shared points if they are identical to the actually used points
 			auxData = self.compileDeltas(sharedPoints)
+			usesSharedPoints = True
 		else:
 			flags |= PRIVATE_POINT_NUMBERS
-			points = self.getUsedPoints()
 			numPointsInGlyph = len(self.coordinates)
 			auxData = self.compilePoints(points, numPointsInGlyph) + self.compileDeltas(points)
+			usesSharedPoints = False
 
 		tupleData = struct.pack('>HH', len(auxData), flags) + bytesjoin(tupleData)
-		return (tupleData, auxData)
+		return (tupleData, auxData, usesSharedPoints)
 
 	def compileCoord(self, axisTags):
 		result = []
@@ -499,32 +502,31 @@ def compileTupleVariationStore(variations, pointCount,
 	# For the time being, we try two variants and then pick the better one:
 	# (a) each tuple supplies its own private set of points;
 	# (b) all tuples refer to a shared set of points, which consists of
-	#     "every control point in the glyph".
-	allPoints = set(range(pointCount))
+	#     "every control point in the glyph that has explicit deltas".
+	usedPoints = set()
+	for v in variations:
+		usedPoints |= v.getUsedPoints()
 	tuples = []
 	data = []
 	someTuplesSharePoints = False
+	sharedPointVariation = None # To keep track of a variation that uses shared points
 	for v in variations:
-		privateTuple, privateData = v.compile(
+		privateTuple, privateData, _ = v.compile(
 			axisTags, sharedTupleIndices, sharedPoints=None)
-		sharedTuple, sharedData = v.compile(
-			axisTags, sharedTupleIndices, sharedPoints=allPoints)
-		# TODO: Apple macOS 10.9.5 (maybe also earlier) up to 10.12 had a bug
-		# that broke variations if the `gvar` table contains shared tuples.
-		# Apple will likely fix this in macOS 10.13. But for the time being,
-		# we never emit shared points although the result would be more compact.
-		# https://rawgit.com/unicode-org/text-rendering-tests/master/reports/CoreText.html#GVAR-1
-		#if (len(sharedTuple) + len(sharedData)) < (len(privateTuple) + len(privateData)):
-		if False:
+		sharedTuple, sharedData, usesSharedPoints = v.compile(
+			axisTags, sharedTupleIndices, sharedPoints=usedPoints)
+		if (len(sharedTuple) + len(sharedData)) < (len(privateTuple) + len(privateData)):
 			tuples.append(sharedTuple)
 			data.append(sharedData)
-			someTuplesSharePoints = True
+			someTuplesSharePoints |= usesSharedPoints
+			sharedPointVariation = v
 		else:
 			tuples.append(privateTuple)
 			data.append(privateData)
 	if someTuplesSharePoints:
-		data = bytechr(0) + bytesjoin(data)  # 0x00 = "all points in glyph"
-		tupleVariationCount = tv.TUPLES_SHARE_POINT_NUMBERS | len(tuples)
+		# Use the last of the variations that share points for compiling the packed point data
+		data = sharedPointVariation.compilePoints(usedPoints, len(sharedPointVariation.coordinates)) + bytesjoin(data)
+		tupleVariationCount = TUPLES_SHARE_POINT_NUMBERS | len(tuples)
 	else:
 		data = bytesjoin(data)
 		tupleVariationCount = len(tuples)
