@@ -233,17 +233,19 @@ class OTTableWriter(object):
 	def __getitem__(self, name):
 		return self.localState[name]
 
+	def __delitem__(self, name):
+		del self.localState[name]
+
 	# assembler interface
 
 	def getDataLength(self):
 		"""Return the length of this table in bytes, without subtables."""
 		l = 0
 		for item in self.items:
-			if hasattr(item, "getData") or hasattr(item, "getCountData"):
-				if item.longOffset:
-					l = l + 4  # sizeof(ULong)
-				else:
-					l = l + 2  # sizeof(UShort)
+			if hasattr(item, "getCountData"):
+				l += item.size
+			elif hasattr(item, "getData"):
+				l += 4 if item.longOffset else 2
 			else:
 				l = l + len(item)
 		return l
@@ -508,16 +510,17 @@ class CountReference(object):
 		else:
 			assert table[name] == value, (name, table[name], value)
 	def getCountData(self):
-		assert self.size in (2, 4)
 		v = self.table[self.name]
 		if v is None: v = 0
-		return packUShort(v) if self.size == 2 else packULong(v)
+		return {1:packUInt8, 2:packUShort, 4:packULong}[self.size](v)
 
 
+def packUInt8 (value):
+	return struct.pack(">B", value)
+
 def packUShort(value):
 	return struct.pack(">H", value)
 
-
 def packULong(value):
 	assert 0 <= value < 0x100000000, value
 	return struct.pack(">L", value)
@@ -604,8 +607,13 @@ class BaseTable(object):
 						table["ExtensionLookupType"])
 			if conv.name == "FeatureParams":
 				conv = conv.getConverter(reader["FeatureTag"])
+			if conv.name == "SubStruct":
+				conv = conv.getConverter(reader.tableTag,
+				                         table["MorphType"])
 			if conv.repeat:
-				if conv.repeat in table:
+				if isinstance(conv.repeat, int):
+					countValue = conv.repeat
+				elif conv.repeat in table:
 					countValue = table[conv.repeat]
 				else:
 					# conv.repeat is a propagated count
@@ -650,7 +658,9 @@ class BaseTable(object):
 				if value is None:
 					value = []
 				countValue = len(value) - conv.aux
-				if conv.repeat in table:
+				if isinstance(conv.repeat, int):
+					assert len(value) == conv.repeat, 'expected %d values, got %d' % (conv.repeat, len(value))
+				elif conv.repeat in table:
 					CountReference(table, conv.repeat, value=countValue)
 				else:
 					# conv.repeat is a propagated count
@@ -776,7 +786,6 @@ class FormatSwitchingBaseTable(BaseTable):
 
 	def readFormat(self, reader):
 		self.Format = reader.readUShort()
-		assert self.Format != 0, (self, reader.pos, len(reader.data))
 
 	def writeFormat(self, writer):
 		writer.writeUShort(self.Format)
